@@ -28,7 +28,6 @@ expr_substitute <- dplyr$expr_substitute
 get_slice_size <- dplyr$get_slice_size
 group_by_drop_default <- dplyr$group_by_drop_default
 group_keys0 <- dplyr$group_keys0
-is_compatible <- dplyr$is_compatible
 is_cross_by <- dplyr$is_cross_by
 join_by_common <- dplyr$join_by_common
 join_cols <- dplyr$join_cols
@@ -45,7 +44,6 @@ tally_n <- dplyr$tally_n
 # Only for dead legacy code?
 add_count_impl <- dplyr$add_count_impl
 arrange_rows <- dplyr$arrange_rows
-check_compatible <- dplyr$check_compatible
 check_frac <- dplyr$check_frac
 check_size <- dplyr$check_size
 coalesce <- dplyr$coalesce
