@@ -2,8 +2,7 @@ test_that("head(2)", {
   withr::local_envvar(DUCKPLYR_FORCE = TRUE)
 
   out <-
-    data.frame(a = 1:5) %>%
-    duckplyr::as_duckplyr_df() %>%
+    duckdb_tibble(a = 1:5) %>%
     head(2)
 
   expect_identical(out$a, 1:2)
@@ -13,8 +12,7 @@ test_that("head(-2)", {
   withr::local_envvar(DUCKPLYR_FORCE = FALSE)
 
   out <-
-    data.frame(a = 1:5) %>%
-    duckplyr::as_duckplyr_df() %>%
+    duckdb_tibble(a = 1:5) %>%
     head(-2)
 
   expect_identical(out$a, 1:3)
@@ -24,8 +22,7 @@ test_that("head(0)", {
   withr::local_envvar(DUCKPLYR_FORCE = TRUE)
 
   out <-
-    data.frame(a = 1:5) %>%
-    duckplyr::as_duckplyr_df() %>%
+    duckdb_tibble(a = 1:5) %>%
     head(0)
 
   expect_identical(out$a, integer(0))
