@@ -7,7 +7,7 @@ test_that("promises work as expected", {
     is_promise <- function(x) .Call(is_promise, x)
 
     expect_true(is_promise(.Call(promise, producer)))
-    expect_true(.Call(promise, producer) |> is_promise())
+    expect_true(.Call(promise, producer) %>% is_promise())
 
     p <- .Call(promise, producer)
     expect_false(is_promise(p))
